import java.awt.Frame;
import javax.swing.BorderFactory;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;

/**
 * This class demonstrates the usage of the StandardDialog class.
 */
public class CustomerDialog extends StandardDialog
{
    // Constants

    private static final String[] COUNTRY_LIST =
    {
        "Australia", "England", "Japan", "USA"
    };

    // Attributes

    private JTextField myCustomerCodeField = new JTextField();
    private JTextField myNameField = new JTextField();
    private JTextArea myAddressField = new JTextArea(3, 20);
    private JTextField myCityField = new JTextField();
    private JTextField myStateField = new JTextField();
    private JTextField myPostcodeField = new JTextField();
    private JComboBox myCountryField = new JComboBox(COUNTRY_LIST);
    private JTextField myContactField = new JTextField();
    private JTextField myPhoneField = new JTextField();
    private JTextField myFaxField = new JTextField();
    private JTextField myEmailField = new JTextField();

    private LabelledItemPanel myContentPane = new LabelledItemPanel();

    // Methods

    /**
     * This method is the default constructor.
     */
    public CustomerDialog()
    {
        init();
    }

    /**
     * This method initialises the components on the panel.
     */
    private void init()
    {
        setTitle("Customer Dialog (StandardDialog)");

        myContentPane.setBorder(BorderFactory.createEtchedBorder());

        myContentPane.addItem("Customer Code", myCustomerCodeField);
        myContentPane.addItem("Name", myNameField);
        myContentPane.addItem("Address", new JScrollPane(myAddressField,
            JScrollPane.VERTICAL_SCROLLBAR_ALWAYS,
            JScrollPane.HORIZONTAL_SCROLLBAR_NEVER));
        myContentPane.addItem("City", myCityField);
        myContentPane.addItem("State", myStateField);
        myContentPane.addItem("Postcode", myPostcodeField);
        myContentPane.addItem("Country", myCountryField);
        myContentPane.addItem("Contact", myContactField);
        myContentPane.addItem("Phone", myPhoneField);
        myContentPane.addItem("Fax", myFaxField);
        myContentPane.addItem("Email", myEmailField);

        setContentPane(myContentPane);
    }

    /**
     * This method gets the values of the panel entry fields.
     *
     * @returns an object containing the Customer data
     */
    public CustomerData getCustomerData()
    {
        CustomerData customerData = new CustomerData();

        customerData.myCustomerCode = myCustomerCodeField.getText();
        customerData.myName = myNameField.getText();
        customerData.myAddress = myAddressField.getText();
        customerData.myCity = myCityField.getText();
        customerData.myState = myStateField.getText();
        customerData.myPostcode = myPostcodeField.getText();
        customerData.myCountry = myCountryField.getSelectedItem().toString();
        customerData.myContact = myContactField.getText();
        customerData.myPhone = myPhoneField.getText();
        customerData.myFax = myFaxField.getText();
        customerData.myEmail = myEmailField.getText();

        return customerData;
    }

    /**
     * This method sets the values of the panel entry fields.
     *
     * @param customerData The object containing the Customer data
     */
    public void setCustomerData(CustomerData customerData)
    {
        myCustomerCodeField.setText(customerData.myCustomerCode);
        myNameField.setText(customerData.myName);
        myAddressField.setText(customerData.myAddress);
        myCityField.setText(customerData.myCity);
        myStateField.setText(customerData.myState);
        myPostcodeField.setText(customerData.myPostcode);
        myCountryField.setSelectedItem(customerData.myCountry);
        myContactField.setText(customerData.myContact);
        myPhoneField.setText(customerData.myPhone);
        myFaxField.setText(customerData.myFax);
        myEmailField.setText(customerData.myEmail);
    }

    /**
     * This method checks that the data entered is valid.
     * To be valid, the following must be met:
     * <LI>Customer Code field is not blank
     * <LI>Name field is not blank
     *
     * @returns <code>true</code> if the data is valid, otherwise
     * <code>false</code>
     */
    protected boolean isValidData()
    {
        if(myCustomerCodeField.getText().equals(""))
        {
            JOptionPane.showMessageDialog(this,
                "Please enter a Customer Code",
                "Blank Customer Code",
                JOptionPane.WARNING_MESSAGE);

            myCustomerCodeField.requestFocus();

            return false;
        }

        if(myNameField.getText().equals(""))
        {
            JOptionPane.showMessageDialog(this,
                "Please enter a Name",
                "Blank Name",
                JOptionPane.WARNING_MESSAGE);

            myNameField.requestFocus();

            return false;
        }

        return true;
    }

    /**
     * This method demonstrates the usage of the CustomerDialog class.
     */
    public static void main(String[] args)
    {
        CustomerDialog dialog = new CustomerDialog();

        dialog.pack();

        // Present it to a User

        dialog.show();

        // Get the data and display it

        if(!dialog.hasUserCancelled())
        {
            CustomerData customerData = dialog.getCustomerData();

            customerData.printData();
        }

        System.exit(0);
    }
}