import java.awt.Frame;
import javax.swing.BorderFactory;
import javax.swing.JComboBox;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;

/**
 * This class implements a LabelledItemPanel for entering Customer data.
 */
public class CustomerPanel extends LabelledItemPanel
{
    // Constants

    private static final String[] COUNTRY_LIST =
    {
        "Australia", "England", "Japan", "USA"
    };

    // Attributes

    private JTextField myCustomerCodeField = new JTextField();
    private JTextField myNameField = new JTextField();
    private JTextArea myAddressField = new JTextArea(3, 20);
    private JTextField myCityField = new JTextField();
    private JTextField myStateField = new JTextField();
    private JTextField myPostcodeField = new JTextField();
    private JComboBox myCountryField = new JComboBox(COUNTRY_LIST);
    private JTextField myContactField = new JTextField();
    private JTextField myPhoneField = new JTextField();
    private JTextField myFaxField = new JTextField();
    private JTextField myEmailField = new JTextField();

    // Methods

    /**
     * This method is the default constructor.
     */
    public CustomerPanel()
    {
        init();
    }

    /**
     * This method initialises the components on the panel.
     */
    private void init()
    {
        setBorder(BorderFactory.createEtchedBorder());

        addItem("Customer Code", myCustomerCodeField);
        addItem("Name", myNameField);
        addItem("Address", new JScrollPane(myAddressField,
            JScrollPane.VERTICAL_SCROLLBAR_ALWAYS,
            JScrollPane.HORIZONTAL_SCROLLBAR_NEVER));
        addItem("City", myCityField);
        addItem("State", myStateField);
        addItem("Postcode", myPostcodeField);
        addItem("Country", myCountryField);
        addItem("Contact", myContactField);
        addItem("Phone", myPhoneField);
        addItem("Fax", myFaxField);
        addItem("Email", myEmailField);
    }

    /**
     * This method gets the values of the panel entry fields.
     *
     * @returns an object containing the Customer data
     */
    public CustomerData getCustomerData()
    {
        CustomerData customerData = new CustomerData();

        customerData.myCustomerCode = myCustomerCodeField.getText();
        customerData.myName = myNameField.getText();
        customerData.myAddress = myAddressField.getText();
        customerData.myCity = myCityField.getText();
        customerData.myState = myStateField.getText();
        customerData.myPostcode = myPostcodeField.getText();
        customerData.myCountry = myCountryField.getSelectedItem().toString();
        customerData.myContact = myContactField.getText();
        customerData.myPhone = myPhoneField.getText();
        customerData.myFax = myFaxField.getText();
        customerData.myEmail = myEmailField.getText();

        return customerData;
    }

    /**
     * This method sets the values of the panel entry fields.
     *
     * @param customerData The object containing the Customer data
     */
    public void setCustomerData(CustomerData customerData)
    {
        myCustomerCodeField.setText(customerData.myCustomerCode);
        myNameField.setText(customerData.myName);
        myAddressField.setText(customerData.myAddress);
        myCityField.setText(customerData.myCity);
        myStateField.setText(customerData.myState);
        myPostcodeField.setText(customerData.myPostcode);
        myCountryField.setSelectedItem(customerData.myCountry);
        myContactField.setText(customerData.myContact);
        myPhoneField.setText(customerData.myPhone);
        myFaxField.setText(customerData.myFax);
        myEmailField.setText(customerData.myEmail);
    }

    /**
     * This method demonstrates the usage of the CustomerPanel class.
     */
    public static void main(String[] args)
    {
        // Create an instance of the panel

        CustomerPanel panel = new CustomerPanel();

        // Create a dialog to hold the panel

        StandardDialog dialog = new StandardDialog(
            (Frame)null, "Customer Details (LabelledItemPanel)");

        dialog.setContentPane(panel);

        dialog.pack();

        // Present it to a User

        dialog.show();

        // Get the data and display it

        if(!dialog.hasUserCancelled())
        {
            CustomerData customerData = panel.getCustomerData();

            customerData.printData();
        }

        System.exit(0);
    }
}